#------------------------------------------------------------------------
# Universidade Estadual de Santa Cruz - UESC
# CET076 - Metodologia e Estatstica Experimental
# Curso: Agronomia
# Prof.: Jos Cludio Faria
# Grupo: Cid Edson Mendona Pvoas
#        Stephane Sacramento
#        Gildo Linhares
#        Dandara Oliveira
# Obs: Recorrigido em 20/12/2022 09:54:25 por J.C.Faria:
#      - devido a nova capacidade do pacote TukeyC de combinar os
#        erros na comparao do efeito do fator alocado a parcela
#        dentro dos nveis do fator alocado a subparcela,
#        que embora - agora possvel, no  muito usual
#------------------------------------------------------------------------
# Objetivos:
# Exemplificar sript com um experimento em Parcela Subdivididas,
# realizando anlise de varincia (ANOVA), teste de comparao de mdias
# e anlise de contrastes
#------------------------------------------------------------------------

#. Leitura e transformao de dados
psd <- read.table('efps.txt',
                  colClasses=c('factor', 
                               'factor', 
                               'factor', 
                               'integer'),
                  header=T)

str(psd)

# Visualiza no vizualidor do R
View(psd)

#.. Adaptao dos dados
# Renomear cultivares (nomes muito longos) para facilitar visualizaes grficas
levels(psd$Cult)
levels(psd$Cult) <- c('Eb', 
                      'Em', 
                      'It', 
                      'Ra')
str(psd)

head(psd,
     10)

tail(psd,
     10)

#. Anlises grficas
## Observar que a ordem natural crescente do fator POCA (Epoc)  pelos catacteres: (D)_Dez, (N)_Nov e (O)_Out
psd$Epoc[order(psd$Epoc)]

#... O reordenamento da base de dados (psd), ordenando pelas pocas do ano crescente: Out  ->  Nov -> Dez
#... ir facilitar a vizualizao e ornar mais lgicas as anlises grficas
psd$Epoc <- factor(psd$Epoc,
                   c('Out', 
                     'Nov', 
                     'Dez'))
                     
psd$Epoc[order(psd$Epoc)]

#.. Bloco x poca:
str(psd)
boxplot(Ger ~ Bloco*Epoc, 
        data=psd,
        col=2:4,
        xlab='Bloco x poca',
        ylab='Germinao')

legend(x=8, 
       y=75, 
       cex=0.9, 
       bty='n',
       fill=c(2:4), 
       legend=c('Bloco 1',
                'Bloco 2',
                'Bloco 3'))

#.. Separando as pocas visualmente:
abline(v=3.5, 
       lty='dashed')

abline(v=6.5, 
       lty='dashed')


#.. Cultivar x poca:
boxplot(Ger ~ Cult*Epoc, 
        data=psd,
        col=2:5,
        xlab='Cultivar x poca',
        ylab='Germinao')

legend(x=11,
       y=75, 
       cex=0.9, 
       bty='n',
       fill=c(2:5), 
       legend=c('Eb', 
                'Em', 
                'It', 
                'Ra'))

#.. Separando as pocas visualmente:
abline(v=4.5, 
       lty='dashed')

abline(v=8.5, 
       lty='dashed')

#.. Visualizao dos efeitos de interao:
#... Cultivar no eixo X
dev.new()
par(mfrow=c(2,1))
with(psd,
     interaction.plot(Cult, Epoc, Ger,
                      ylab='Germinao(%)',
                      xlab='Cultivar',
                      col=1:4,
                      lwd=2))                      

#... poca no eixo X
with(psd,
     interaction.plot(Epoc, Cult, Ger,
                      ylab='Germinao (%)',
                      xlab='poca',
                      col=1:4,
                      lwd=2))


#. ANOVA
#... Fatorial normal
#av <- aov(Ger ~ Bloco + Cult + Epoc + Cult*Epoc,
#          data=psd)

#... Parcela subdividida (necessrio informar o erro asscociado as parcelas (Cult))
av <- aov(Ger ~ Bloco + Cult + Epoc + Cult*Epoc + Error(Bloco/Cult),
          data=psd)

summary(av)

str(summary(av))

#... Pacote necessrio: TukeyC
library(TukeyC)

# cv: coeficiente de variao:  uma funo do pacote TukeyC
cv(av)

#. Testes de comparao de mdias
#.. Efeitos principais
# OBS: como a interao  significativa o teste ser aplicado apenas com objetivos de aprender
# como testar os efeitos principais. O correto  desdobrar a interao!

#... Efeito principal de Cultivar
tk_p <- TukeyC(av,
              which='Cult',
              error='Bloco:Cult',
              sig.level=0.05)
summary(tk_p)

#... Efeito principal de poca
tk_sp <- TukeyC(av,
                which='Epoc',
                error='Within',
                sig.level=0.05)
summary(tk_sp)

#.. Efeitos das interaes
#.. Cult/Epoc: efeito da poca em cada cultivar
# Como POCA (Epoc) est associado a subparcela, usar o erro associado a subparcela: 
# 'Whithin'

#.. Eb/Epoc
tk_eb <- TukeyC(av,
                which='Cult:Epoc',
                error='Within',
                fl1=1)
summary(tk_eb)

#.. Em/Epoc
tk_em <- TukeyC(av,
                which='Cult:Epoc',
                error='Within',
                fl1=2)
summary(tk_em)

#.. It/Epoc
tk_it <- TukeyC(av,
                which='Cult:Epoc',
                error='Within',
                fl1=3)
summary(tk_it)

#.. Ra/Epoc
tk_ra <- TukeyC(av,
                which='Cult:Epoc',
                error='Within',
                fl1=4)
summary(tk_ra)

#.. Epoc/Cult: cultivares em cada nvel de poca
# Necessrio usar combinao dos erros: 'Within/Bloco:Cult'
#
# Ou seja, comparar os nveis do fator alocado PARCELA (Cult)
# em cada nvel do fator alocado a SUBPARCELA (Epoc)

#.. Out/Cul
tk_out <- TukeyC(av,
                 which='Epoc:Cult',
                 error='Within/Bloco:Cult',  # informa a combinao necessria dos erros
                 fl1=1)
summary(tk_out)

#.. Nov/Cul
tk_nov <- TukeyC(av,
                 which='Epoc:Cult',
                 error='Within/Bloco:Cult',  # informa a combinao necessria dos erros
                 fl1=2)
summary(tk_nov)

#.. Dez/Epoc
tk_dez <- TukeyC(av,
                 which='Epoc:Cult',
                 error='Within/Bloco:Cult',  # informa a combinao necessria dos erros
                 fl1=3)
summary(tk_dez)

#. Pacote alternativo para anlise de varincia e teste de comparao de mdias: ExpDes
# install.packages(ExpDes.pt), caso no possua
library(ExpDes.pt)
str(psub2.dbc)
psub2.dbc(psd$Cult,
          psd$Epoc,
          psd$Bloco,
          psd$Ger,
          fac.names = c('Cultivar',
                        'poca'))

#. Contrastes
#.. Matriz de contrastes das pocas
                                    # Out Nov Dez
mce <- rbind('_Out vs. (Nov, Dez)' = c(2, -1, -1),
             '_Nov vs. Dez'        = c(0,  1, -1))

# Pacote gmodels  necessrio para a funo: make.contrasts (abaixo)
if(!require(gmodels)) install.packages(gmodels); (library(gmodels))

# Necessrio aninhar os efeitos para o desdobramento correto em contrastes ortogonais
# Observar:
#  - argumento 'contrasts' conjuntamente com a funo 'summary' com o argumento 'split'
#  - mudana no modelo em relao ao anterior (av1): aninhamento do
#  - efeitos de poca juntamente com a interao Cult:Epoc.

av_c <- aov(Ger ~ Bloco + Cult + Cult/Epoc + Error(Bloco/Cult),
            data=psd,
            contrasts=list('Epoc'=make.contrasts(mce)))

coef(av_c)

sm <- summary(av_c,
              split=list('Cult:Epoc'=list('Eb/Epoc*'              = c(1, 5),
                                          'Eb/Out vs. (Nov, Dez)' = 1,
                                          'Eb/Nov vs. Dez'        = 5,
                                          'Em/Epoc*'              = c(2, 6),
                                          'Em/Out vs. (Nov, Dez)' = 2,
                                          'Em/Nov vs. Dez'        = 6,
                                          'It/Epoc*'              = c(3, 7),
                                          'It/Out vs. (Nov, Dez)' = 3,
                                          'It/Nov vs. Dez'        = 7,
                                          'Ra/Epoc*'              = c(4, 8),
                                          'Ra/Out vs. (Nov, Dez)' = 4,
                                          'Ra/Nov vs. Dez'        = 8
                                          )))

sm 
# ANOVA
#----------------------------------------------------------------------------
#                                   Df Sum Sq Mean Sq F value     Pr(>F)
# Bloco                               2  10.72   5.361
# Cult                                3 1050.8   350.2   65.33   5.67e-05 ***
# Residuals(a)                        6   32.2     5.4
#----------------------------------------------------------------------------
# Cult:Epoc                           8   4346   543.2  26.624 7.74e-08 ***
#----------------------------------------------------------------------------
# Cult:Epoc: Eb/Epoc*                 2   1928   964.0  47.248 1.93e-07 ***
#----------------------------------------------------------------------------
# Cult:Epoc: Eb/Out vs. (Nov, Dez)    1   1922  1922.0  94.203 4.15e-08 ***
# Cult:Epoc: Eb/Nov vs. Dez           1      6     6.0   0.294   0.5951
#----------------------------------------------------------------------------
# Cult:Epoc: Em/Epoc*                 2    122    61.0   2.990   0.0789 .
#----------------------------------------------------------------------------
# Cult:Epoc: Em/Out vs. (Nov, Dez)    1     98    98.0   4.803   0.0435 *
# Cult:Epoc: Em/Nov vs. Dez           1     24    24.0   1.176   0.2942
#----------------------------------------------------------------------------
# Cult:Epoc: It/Epoc*                 2   2246  1123.0  55.042 6.73e-08 ***
#----------------------------------------------------------------------------
# Cult:Epoc: It/Out vs. (Nov, Dez)    1   2244  2244.5 110.010 1.41e-08 ***
# Cult:Epoc: It/Nov vs. Dez           1      2     1.5   0.074   0.7897
#----------------------------------------------------------------------------
# Cult:Epoc: Ra/Epoc*                 2     50    24.8   1.214   0.3228
#----------------------------------------------------------------------------
# Cult:Epoc: Ra/Out vs. (Nov, Dez)    1      1     1.4   0.068   0.7975
# Cult:Epoc: Ra/Nov vs. Dez           1     48    48.2   2.361   0.1440
#----------------------------------------------------------------------------
# Residuals(b)                       16    326    20.4
#----------------------------------------------------------------------------
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
